function find_sun_center,image, xcen, ycen, rsun
;----------------------------------------------
;
; This function looks for the solar center in EUV images.
; The image is transformed to polar coordinates. 
; We then take the radial gradient of the the polar transformed image.
; This gives a clear sinusoidal wave at the limb position.
; A modified Hough transform is applied to fit several sinusses.
; The best fitting sinus is used and back-transformed to find an improved disk center.
; If the modification is less than 3 pixels, we exit.
;
; usage: center=find_sun_center(image, 1024,1024, 622.751)
;
; 'image' is input image
; 'xcen, ycen' is initial guess of solar center location in pixel coordinates
; 'rsun' is solar radius. It is assumed that this is known precisely.
;
; First version 20070220, D. Berghmans
; 
;
;----------------------------------------------

sz=size(image)
maxx=sz(1)
maxy=sz(2)

tdim=1024
rdim=1024
namp=201
nphase=tdim

out=fltarr(tdim,rdim)
polar=fltarr(tdim,rdim)


REPEAT BEGIN

        print, xcen, ycen

        FOR t= 0, tdim-1 DO BEGIN
           FOR r= 0, rdim-1 DO BEGIN
             x=xcen+r*((0.5*maxx)/(rdim-1))*cos(t*(2*!pi)/(tdim-1))
             y=ycen+r*((0.5*maxy)/(rdim-1))*sin(t*(2*!pi)/(tdim-1))
             IF (x Gt 0) and (y GT 0) and (x lt maxx) and (y lt maxy) then polar(t,r)=image(x,y)   
           ENDFOR
        ENDFOR

        for i=1,rdim-1 do out[*,i]=polar[*,i]-polar[*,i-1]
        out=(out<100)>0

        hough=fltarr(namp,nphase)
        tvector=indgen(tdim)
        for amp=0,namp-1 do begin
                for phase=0, nphase-1 do begin
                        rvector= round( amp *sin(2 * (!pi /(nphase-1)) * (tvector +phase)) + rsun)
                        vector=tvector+rvector*long(tdim)
                        hough[amp, phase] =total(out[vector]) 
                endfor
        endfor

        peak=max(hough,peakpos)
        peakpos_phase           =peakpos/namp
        peakpos_amp                     =peakpos - namp*peakpos_phase
        xcen= xcen + peakpos_amp* sin(2 * !pi *  peakpos_phase / (nphase-1))
        ycen= ycen + peakpos_amp* cos(2 * !pi *  peakpos_phase / (nphase-1))

ENDREP UNTIL peakpos_amp LT 3
return, [xcen,ycen]
END
